@@ -1,10 +1,11 @@
 package Panda::Install;
 use strict;
 use warnings;
+use Config;
 use Exporter 'import';
 use Panda::Install::Payload;
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.2.2';
 
 =head1 NAME
 
@@ -121,6 +122,8 @@ sub makemaker_args {
     
     delete $params{MODULE_INFO};
 
+    $params{CCFLAGS} = "$Config{ccflags} $params{CCFLAGS}";
+
     return %params;
 }
 
