@@ -102,8 +102,8 @@ package
 use strict;
 use warnings;
 
-    # pre process     # post process
-my ($orig_fetch_para, $orig_print_section);
+    # pre process     # post process       # after preprocess
+my ($orig_fetch_para, $orig_print_section, $after_fetch_para);
 
 BEGIN {
     $orig_fetch_para = \&fetch_para;
@@ -115,6 +115,12 @@ BEGIN {
     delete ${__PACKAGE__.'::'}{eval_input_typemap_code};
 }
 
+BEGIN {
+    eval {require inc::MY::ParseXS; 1} and do {
+        $after_fetch_para = *inc::MY::ParseXS::after_fetch_para{CODE};
+    };
+}
+
 # pre process XS function
 sub fetch_para {
     my $self = shift;
@@ -127,9 +133,10 @@ sub fetch_para {
         if ($lines->[-1] =~ /^\}/) { pop @$lines; pop @$linno; }
     }
     
-    my $re_alias = qr/ALIAS\s*\(([^()]+)\)/;
-    if ($lines->[0] and $lines->[0] =~ /^(.+?)\s+([^\s()]+\s*(\((?:[^()]+|(?3))*\)))\s*(?::\s*(?:$re_alias)?)?\s*\{?/) {
-        my ($type, $sig, $alias) = ($1, $2, $4);
+    if ($lines->[0] and $lines->[0] =~ /^(.+?)\s+([^\s()]+\s*(\((?:[^()]+|(?3))*\)))\s*(.*)/) {
+        my ($type, $sig, $attrs) = ($1, $2, $4);
+        $self->{_xsub_attrs} = { $attrs =~ /:\s*([A-Z]+)\s*(?:\(([^()]*)\)|)\s*/gc };
+        my $alias = $self->{_xsub_attrs}->{ALIAS};
         my $remove_closing;
         
         if ((my $idx = index($lines->[0], '{')) > 0) { # move following text on next line
@@ -193,6 +200,8 @@ sub fetch_para {
         
         splice(@$lines, 1, 0, $sig);
         splice(@$linno, 1, 0, $linno->[0]);
+    } else {
+        %{$self->{_xsub_attrs}} = ();
     }
 
     my $para = join("\n", @$lines);
@@ -218,6 +227,8 @@ sub fetch_para {
         splice(@$lines, $idx, 0, $init_code);
         splice(@$linno, $idx, 0, $linno->[0]);
     }}
+
+    $after_fetch_para->($self) if $after_fetch_para;
     
     return $ret;
 }
